package # hide from PAUSE
    MyBlog::Model::DBIC;

use strict;
use base qw(Catalyst::Model::DBIC::Schema);
1;
